@@ -107,9 +107,7 @@ Opendap server, implemented as a WSGI application.
     ),
     deploy=Bunch(
         htmldir = path('pydap.org'),
-        username = 'roberto',
-        host = 'pydap.org',
-        hostpath = '/var/www/sites/pydap.org-3.x/'
+        bucket = 'pydap.org',
     ),
 )
 
@@ -153,6 +151,18 @@ def sdist():
 ])
 def deploy():
     """Deploy the HTML to the server."""
-    sh("rsync -avz -e ssh %s/ %s@%s:%s" % (options.htmldir,
-            options.username, options.host, options.hostpath))
+    import os
+    from boto.s3.connection import S3Connection
+    from boto.s3.key import Key
 
+    conn = S3Connection()
+    bucket = conn.create_bucket(options.bucket)
+    bucket.set_acl('public-read')
+
+    for root, dirs, files in os.walk(options.htmldir):
+        for file in files:
+            path = os.path.join(root, file)
+            k = Key(bucket)
+            k.key = path[len(options.htmldir)+1:]  # strip pydap.org/
+            k.set_contents_from_filename(path)
+            k.set_acl('public-read')
