@@ -521,10 +521,9 @@ class SequenceType(StructureType):
 
         """
         data = copy.deepcopy(self.data)
-        data = [el for el in data]  # download data before extracting columns
-        cols = (get_row(data, i, self._nesting_level) for
-                i, k in enumerate(self.keys()))
-        for row in zip(*cols):
+        for row in data:
+            # XXX test with nested arrays.
+            row = [get_row(row, i, self._nesting_level-1) for i, k in enumerate(self.keys())]
             struct_ = StructureType(self.name, self.attributes.copy())
             for col, name in zip(row, self.keys()):
                 var = struct_[name] = copy.deepcopy(self[name])
