@@ -144,22 +144,24 @@ class DASParser(SimpleParser):
                 if value.lower() in ['nan', 'nan.']:
                     value = numpy.NaN
                 else:
-                    value = expr_eval(value)
-
-                # Convert to proper type. This is specially important for floats,
-                # since this preserves the resolution even though Python has no
-                # difference between float 32 vs. 64.
-                dtype = {'float64': 'd',
-                         'float32': 'f',
-                         'int32'  : 'l',
-                         'int16'  : 'h',
-                         'uint32' : 'L',
-                         'uint16' : 'H',
-                         'byte'   : 'B'}[type_.lower()]
-                try:
-                    value = array.array(dtype, [value])[0]
-                except OverflowError:
-                    value = long(value)
+                    # Convert to proper type. This is specially important for floats,
+                    # since this preserves the resolution even though Python has no
+                    # difference between float 32 vs. 64.
+                    dtype = {'float64': 'd',
+                             'float32': 'f',
+                             'int32'  : 'l',
+                             'int16'  : 'h',
+                             'uint32' : 'L',
+                             'uint16' : 'H',
+                             'byte'   : 'B'}[type_.lower()]
+                    if dtype in ['d', 'f']:
+                        value = array.array(dtype, [float(value)])[0]
+                    else:
+                        value = expr_eval(value)
+                        try:
+                            value = int(value)
+                        except OverflowError:
+                            value = long(value)
 
             values.append(value)
             if self.peek(','):
